@@ -24,20 +24,20 @@
 #include <KCharsets>
 #include <KComboBox>
 #include <KConfig>
-#include <QFontComboBox>
 #include <KConfigGroup>
-#include <KSharedConfig>
 #include <KLocalizedString>
-#include <QSpinBox>
+#include <KSharedConfig>
 
 #include <khtmldefaults.h>
 
+#include <QDialogButtonBox>
+#include <QFontComboBox>
+#include <QFontDatabase>
 #include <QGroupBox>
 #include <QLabel>
 #include <QLayout>
-#include <qfontdatabase.h>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QSpinBox>
 #include <QVBoxLayout>
 
 #include <prefs.h>
@@ -60,8 +60,8 @@ FontDialog::FontDialog( QWidget *parent )
   QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
   okButton->setDefault(true);
   okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-  connect(buttonBox, SIGNAL(accepted()), this, SLOT(slotOk()));
-  connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+  connect(buttonBox, &QDialogButtonBox::accepted, this, &FontDialog::slotOk);
+  connect(buttonBox, &QDialogButtonBox::rejected, this, &FontDialog::reject);
   mainLayout->addWidget(buttonBox);
 
   load();
@@ -176,7 +176,7 @@ void FontDialog::load()
   {
     KConfigGroup configGroup( cfg, "HTML Settings" );
 
-    m_minFontSize->setValue( configGroup.readEntry( "MinimumFontSize", (int)HTML_DEFAULT_MIN_FONT_SIZE ) );
+    m_minFontSize->setValue( configGroup.readEntry( "MinimumFontSize", static_cast<int>(HTML_DEFAULT_MIN_FONT_SIZE) ) );
     m_medFontSize->setValue( configGroup.readEntry( "MediumFontSize", 10 ) );
 
     QStringList fonts = configGroup.readEntry( "Fonts" , QStringList() );
