@@ -23,20 +23,19 @@
 #include "view.h"
 #include "khc_debug.h"
 
-#include <KXmlGuiWindow>
 #include <KProcess>
-#include <QStatusBar>
+#include <KXmlGuiWindow>
 
-#include <QTreeWidgetItem>
-
-#include <qapplication.h>
-#include <QTextStream>
-
-#include <sys/stat.h>
-#include <QStandardPaths>
+#include <QApplication>
 #include <QDir>
 #include <QFileInfo>
 #include <QIcon>
+#include <QStandardPaths>
+#include <QStatusBar>
+#include <QTextStream>
+#include <QTreeWidgetItem>
+
+#include <sys/stat.h>
 
 #include <prefs.h>
 
@@ -49,7 +48,7 @@ class SectionItem : public QTreeWidgetItem
         : QTreeWidgetItem( parent )
         {
           setText(0,text);
-          setIcon(0,QIcon::fromTheme( "help-contents" ));
+          setIcon(0,QIcon::fromTheme( QStringLiteral("help-contents") ));
         }
 };
 
@@ -75,8 +74,7 @@ Glossary::Glossary( QWidget *parent ) : QTreeWidget( parent )
     m_initialized = false;
     setFrameStyle( QFrame::NoFrame );
 
-    connect( this, SIGNAL( itemActivated(QTreeWidgetItem *, int) ),
-             this, SLOT( treeItemSelected( QTreeWidgetItem * ) ) );
+    connect(this, &Glossary::itemActivated, this, &Glossary::treeItemSelected);
 
     setHeaderHidden(true);
     setAllColumnsShowFocus( true );
@@ -84,16 +82,16 @@ Glossary::Glossary( QWidget *parent ) : QTreeWidget( parent )
 
     m_byTopicItem = new QTreeWidgetItem( this );
     m_byTopicItem->setText( 0, i18n( "By Topic" ) );
-    m_byTopicItem->setIcon( 0, QIcon::fromTheme( "help-contents" ) );
+    m_byTopicItem->setIcon( 0, QIcon::fromTheme( QStringLiteral("help-contents") ) );
 
     m_alphabItem = new QTreeWidgetItem( this );
     m_alphabItem->setText( 0, i18n( "Alphabetically" ) );
-    m_alphabItem->setIcon( 0, QIcon::fromTheme( "character-set" ) );
+    m_alphabItem->setIcon( 0, QIcon::fromTheme( QStringLiteral("character-set") ) );
 
-    m_cacheFile = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1Char('/') + "help/glossary.xml" ;
+    m_cacheFile = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1Char('/') + QStringLiteral("help/glossary.xml");
     QDir().mkpath( QFileInfo( m_cacheFile ).absolutePath() );
 
-    m_sourceFile = View::langLookup( QLatin1String( "khelpcenter/glossary/index.docbook" ) );
+    m_sourceFile = View::langLookup( QStringLiteral( "khelpcenter/glossary/index.docbook" ) );
 
 }
 
@@ -146,8 +144,7 @@ void Glossary::rebuildGlossaryCache()
         mainWindow->statusBar()->showMessage( i18n( "Rebuilding glossary cache..." ) );
 
     KProcess *meinproc = new KProcess;
-    connect( meinproc, SIGNAL( finished(int,QProcess::ExitStatus) ),
-             this, SLOT( meinprocFinished(int,QProcess::ExitStatus) ) );
+    connect(meinproc, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &Glossary::meinprocFinished);
 
     *meinproc << QStandardPaths::findExecutable(QStringLiteral( "meinproc5" ) );
     *meinproc << QLatin1String( "--output" ) << m_cacheFile;
@@ -159,7 +156,7 @@ void Glossary::rebuildGlossaryCache()
     meinproc->start();
     if (!meinproc->waitForStarted())
     {
-        khcWarning() << "could not start process" << meinproc->program();
+        qCWarning(KHC_LOG) << "could not start process" << meinproc->program();
         if (mainWindow && !m_alreadyWarned)
         {
             ; // add warning message box with don't display again option
@@ -177,8 +174,8 @@ void Glossary::meinprocFinished( int exitCode, QProcess::ExitStatus exitStatus )
 
     if (exitStatus != QProcess::NormalExit || exitCode != 0)
     {
-        khcWarning() << "running" << meinproc->program() << "failed with exitCode" << exitCode;
-        khcWarning() << "stderr output:" << meinproc->readAllStandardError();
+        qCWarning(KHC_LOG) << "running" << meinproc->program() << "failed with exitCode" << exitCode;
+        qCWarning(KHC_LOG) << "stderr output:" << meinproc->readAllStandardError();
         if (mainWindow && !m_alreadyWarned)
         {
             ; // add warning message box with don't display again option
@@ -301,7 +298,7 @@ void Glossary::slotSelectGlossEntry( const QString &id )
 
     EntryItem *newItem = m_idDict.value( id );
     EntryItem *curItem = dynamic_cast<EntryItem *>( currentItem() );
-    if ( curItem != 0 )
+    if ( curItem != nullptr )
     {
         if ( curItem->id() == id ) {
           return;
