@@ -31,35 +31,34 @@
 #include "bookmarkowner.h"
 
 #include <QAction>
-#include <KActionCollection>
-#include <KConfig>
-#include <QIcon>
-#include <KRun>
-#include <KHTMLView>
-#include <KHTMLSettings>
-#include <QDialog>
-#include <KStandardAction>
-#include <KStartupInfo>
-#include <KConfigGroup>
-#include <KWindowConfig>
-#include <KBookmarkManager>
-#include <KBookmarkMenu>
-#include <KActionMenu>
-
 #include <QDBusConnection>
-#include <QSplitter>
-#include <QTextEdit>
-#include <QVBoxLayout>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QDir>
+#include <QIcon>
 #include <QList>
 #include <QMimeDatabase>
-#include <QStatusBar>
-#include <QDir>
-#include <QTextDocument>
-
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QSplitter>
+#include <QStatusBar>
+#include <QTextDocument>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
-#include <kio/job.h>
+#include <KActionCollection>
+#include <KActionMenu>
+#include <KBookmarkManager>
+#include <KBookmarkMenu>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KHTMLSettings>
+#include <KHTMLView>
+#include <KRun>
+#include <KStandardAction>
+#include <KStartupInfo>
+#include <KWindowConfig>
+
+#include <KIO/Job>
 
 #include <prefs.h>
 
@@ -68,7 +67,7 @@ using namespace KHC;
 class LogDialog : public QDialog
 {
   public:
-    LogDialog( QWidget *parent = 0 )
+    explicit LogDialog( QWidget *parent = nullptr )
       : QDialog( parent )
     {
       setWindowTitle( i18n("Search Error Log") );
@@ -81,8 +80,8 @@ class LogDialog : public QDialog
       mainLayout->addWidget( mTextView );
 
       QDialogButtonBox *buttonBox = new QDialogButtonBox( QDialogButtonBox::Close );
-      connect( buttonBox, SIGNAL( accepted() ), this, SLOT( accept() ) );
-      connect( buttonBox, SIGNAL( rejected() ), this, SLOT( reject() ) );
+      connect( buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept );
+      connect( buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject );
       mainLayout->addWidget( buttonBox );
 
       KConfigGroup cg = KSharedConfig::openConfig()->group( "logdialog" );
@@ -106,47 +105,33 @@ class LogDialog : public QDialog
 
 
 MainWindow::MainWindow()
-    : KXmlGuiWindow(0),
-      mLogDialog( 0 )
+    : KXmlGuiWindow(nullptr),
+      mLogDialog( nullptr )
 {
     setObjectName( QLatin1String( "MainWindow" ) );
 
-    QDBusConnection::sessionBus().registerObject("/KHelpCenter", this, QDBusConnection::ExportScriptableSlots);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/KHelpCenter"), this, QDBusConnection::ExportScriptableSlots);
     mSplitter = new QSplitter( this );
 
     mDoc = new View( mSplitter, this, KHTMLPart::DefaultGUI, actionCollection() );
-    connect( mDoc, SIGNAL( setWindowCaption( const QString & ) ),
-             SLOT( setWindowTitle( const QString & ) ) );
-    connect( mDoc, SIGNAL( setStatusBarText( const QString & ) ),
-             SLOT( statusBarRichTextMessage( const QString & ) ) );
-    connect( mDoc, SIGNAL( onURL( const QString & ) ),
-             SLOT( statusBarMessage( const QString & ) ) );
-    connect( mDoc, SIGNAL( started( KIO::Job * ) ),
-             SLOT( slotStarted( KIO::Job * ) ) );
-    connect( mDoc, SIGNAL( completed() ),
-             SLOT( documentCompleted() ) );
-    connect( mDoc, SIGNAL( searchResultCacheAvailable() ),
-             SLOT( enableLastSearchAction() ) );
+    connect( mDoc, &View::setWindowCaption, this, &MainWindow::setWindowTitle );
+    connect( mDoc, &KParts::Part::setStatusBarText, this, &MainWindow::statusBarRichTextMessage );
+    connect( mDoc, &View::onURL, this, &MainWindow::statusBarMessage );
+    connect( mDoc, &View::started, this, &MainWindow::slotStarted );
+    connect( mDoc, QOverload<>::of(&View::completed), this, &MainWindow::documentCompleted );
+    connect( mDoc, &View::searchResultCacheAvailable, this, &MainWindow::enableLastSearchAction );
 
-    connect( mDoc, SIGNAL( selectionChanged() ),
-             SLOT( enableCopyTextAction() ) );
+    connect( mDoc, &View::selectionChanged, this, &MainWindow::enableCopyTextAction );
 
     statusBar()->showMessage(i18n("Preparing Index"));
 
-    connect( mDoc->browserExtension(),
-             SIGNAL( openUrlRequest( const QUrl &,
-                                     const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) ),
-             SLOT( slotOpenURLRequest( const QUrl &,
-                                       const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) ) );
+    connect( mDoc->browserExtension(), &KParts::BrowserExtension::openUrlRequest, this, &MainWindow::slotOpenURLRequest );
 
     mNavigator = new Navigator( mDoc, mSplitter );
-    mNavigator->setObjectName( "nav" );
-    connect( mNavigator, SIGNAL( itemSelected( const QString & ) ),
-             SLOT( viewUrl( const QString & ) ) );
-    connect( mNavigator, SIGNAL( glossSelected( const GlossaryEntry & ) ),
-             SLOT( slotGlossSelected( const GlossaryEntry & ) ) );
-    connect( mNavigator, SIGNAL( setStatusBarText( const QString & ) ),
-             SLOT( statusBarMessage( const QString & ) ) );
+    mNavigator->setObjectName( QStringLiteral("nav") );
+    connect( mNavigator, &Navigator::itemSelected, this, QOverload<const QString &>::of(&MainWindow::viewUrl) );
+    connect( mNavigator, &Navigator::glossSelected, this, &MainWindow::slotGlossSelected );
+    connect( mNavigator, &Navigator::setStatusBarText, this, &MainWindow::statusBarMessage );
 
     mSplitter->insertWidget(0, mNavigator);
     mSplitter->setStretchFactor(mSplitter->indexOf(mNavigator), 0);
@@ -157,7 +142,7 @@ MainWindow::MainWindow()
 
     {
       if ( Prefs::useKonqSettings() ) {
-        KConfig konqCfg( "konquerorrc" );
+        KConfig konqCfg( QStringLiteral("konquerorrc") );
         const_cast<KHTMLSettings *>( mDoc->settings() )->init( &konqCfg );
       }
       const int fontScaleFactor = Prefs::fontzoomfactor();
@@ -176,10 +161,8 @@ MainWindow::MainWindow()
 
     History::self().installMenuBarHook( this );
 
-    connect( &History::self(), SIGNAL( goInternalUrl( const QUrl & ) ),
-             mNavigator, SLOT( openInternalUrl( const QUrl & ) ) );
-    connect( &History::self(), SIGNAL( goUrl( const QUrl & ) ),
-             mNavigator, SLOT( selectItem( const QUrl & ) ) );
+    connect( &History::self(), &History::goInternalUrl, mNavigator, &Navigator::openInternalUrl );
+    connect( &History::self(), &History::goUrl, mNavigator, &Navigator::selectItem );
 
     statusBarMessage(i18n("Ready"));
     enableCopyTextAction();
@@ -228,61 +211,61 @@ void MainWindow::writeConfig()
 
 void MainWindow::setupActions()
 {
-    actionCollection()->addAction( KStandardAction::Quit, this, SLOT( close() ) );
-    actionCollection()->addAction( KStandardAction::Print, this, SLOT( print() ) );
+    actionCollection()->addAction( KStandardAction::Quit, this, SLOT(close()) );
+    actionCollection()->addAction( KStandardAction::Print, this, SLOT(print()) );
 
-    QAction *prevPage  = actionCollection()->addAction( "prevPage" );
+    QAction *prevPage  = actionCollection()->addAction( QStringLiteral("prevPage") );
     prevPage->setText( i18n( "Previous Page" ) );
     actionCollection()->setDefaultShortcut(prevPage, Qt::CTRL+Qt::Key_PageUp );
     prevPage->setWhatsThis( i18n( "Moves to the previous page of the document" ) );
-    connect( prevPage, SIGNAL( triggered() ), mDoc, SLOT( prevPage() ) );
+    connect( prevPage, &QAction::triggered, mDoc, &View::prevPage );
 
-    QAction *nextPage  = actionCollection()->addAction( "nextPage" );
+    QAction *nextPage  = actionCollection()->addAction( QStringLiteral("nextPage") );
     nextPage->setText( i18n( "Next Page" ) );
     actionCollection()->setDefaultShortcut(nextPage, Qt::CTRL + Qt::Key_PageDown );
     nextPage->setWhatsThis( i18n( "Moves to the next page of the document" ) );
-    connect( nextPage, SIGNAL( triggered() ), mDoc, SLOT( nextPage() ) );
+    connect( nextPage, &QAction::triggered, mDoc, &View::nextPage );
 
-    QAction *home = KStandardAction::home( this, SLOT( slotShowHome() ), this );
+    QAction *home = KStandardAction::home( this, SLOT(slotShowHome()), this );
     actionCollection()->addAction( home->objectName(), home );
     home->setText(i18n("Table of &Contents"));
     home->setToolTip(i18n("Table of contents"));
     home->setWhatsThis(i18n("Go back to the table of contents"));
 
     mCopyText = KStandardAction::copy( this, SLOT(slotCopySelectedText()), this );
-    actionCollection()->addAction( "copy_text", mCopyText );
+    actionCollection()->addAction( QStringLiteral("copy_text"), mCopyText );
 
     mLastSearchAction = actionCollection()->addAction( QLatin1String("lastsearch") );
     mLastSearchAction->setText( i18n("&Last Search Result") );
     mLastSearchAction->setEnabled( false );
-    connect( mLastSearchAction, SIGNAL( triggered() ), this, SLOT( slotLastSearch() ) );
+    connect( mLastSearchAction, &QAction::triggered, this, &MainWindow::slotLastSearch );
 /*
     QAction *action = actionCollection()->addAction( QLatin1String("build_index") );
     action->setText( i18n("Build Search Index...") );
-    connect( action, SIGNAL( triggered() ), mNavigator, SLOT( showIndexDialog() ) );
+    connect( action, &QAction::triggered, mNavigator, &Navigator::showIndexDialog );
 
     KConfigGroup debugGroup( KSharedConfig::openConfig(), "Debug" );
     if ( debugGroup.readEntry( "SearchErrorLog", false) ) {
         action = actionCollection()->addAction(QLatin1String("show_search_stderr"));
         action->setText( i18n("Show Search Error Log") );
-        connect( action, SIGNAL( triggered() ), this, SLOT( showSearchStderr() ) );
+        connect( action, &QAction::triggered, this, &View::showSearchStderr );
     }
 */
     History::self().setupActions( actionCollection() );
 
     QAction *action = actionCollection()->addAction(QLatin1String("configure_fonts" ));
     action->setText( i18n( "Configure Fonts..." ) );
-    connect( action, SIGNAL( triggered() ), this, SLOT( slotConfigureFonts() ) );
+    connect( action, &QAction::triggered, this, &MainWindow::slotConfigureFonts );
 
     action = actionCollection()->addAction(QLatin1String("incFontSizes"));
     action->setText( i18n( "Increase Font Sizes" ) );
     action->setIcon( QIcon::fromTheme( QLatin1String("zoom-in") ) );
-    connect( action, SIGNAL( triggered() ), this, SLOT( slotIncFontSizes() ) );
+    connect( action, &QAction::triggered, this, &MainWindow::slotIncFontSizes );
 
     action = actionCollection()->addAction(QLatin1String("decFontSizes"));
     action->setText( i18n( "Decrease Font Sizes" ) );
     action->setIcon( QIcon::fromTheme( QLatin1String("zoom-out") ) );
-    connect( action, SIGNAL( triggered() ), this, SLOT( slotDecFontSizes() ) );
+    connect( action, &QAction::triggered, this, &MainWindow::slotDecFontSizes );
 }
 
 void MainWindow::setupBookmarks()
@@ -294,7 +277,7 @@ void MainWindow::setupBookmarks()
     KBookmarkManager *manager = KBookmarkManager::managerForFile( file, QStringLiteral( "khelpcenter" ) );
     manager->setParent( this );
     BookmarkOwner *owner = new BookmarkOwner( mDoc, manager );
-    connect( owner, SIGNAL( openUrl( const QUrl & ) ), this, SLOT( openUrl( const QUrl & ) ) );
+    connect( owner, &BookmarkOwner::openUrl, this, QOverload<const QUrl &>::of(&MainWindow::openUrl) );
     KActionMenu *actmenu = actionCollection()->add<KActionMenu>( QStringLiteral( "bookmarks" ) );
     actmenu->setText( i18nc( "@title:menu", "&Bookmarks" ) );
     KBookmarkMenu *bookmenu = new KBookmarkMenu( manager, owner, actmenu->menu(), actionCollection() );
@@ -314,8 +297,7 @@ void MainWindow::print()
 void MainWindow::slotStarted(KIO::Job *job)
 {
     if (job)
-       connect(job, SIGNAL(infoMessage( KJob *, const QString &, const QString &)),
-               SLOT(slotInfoMessage(KJob *, const QString &)));
+       connect(job, &KIO::Job::infoMessage, this, &MainWindow::slotInfoMessage);
 
     History::self().updateActions();
 }
@@ -330,7 +312,7 @@ void MainWindow::slotOpenURLRequest( const QUrl &url,
                                      const KParts::OpenUrlArguments &args,
                                      const KParts::BrowserArguments &browserArgs )
 {
-  khcDebug() << url.url();
+  qCDebug(KHC_LOG) << url.url();
 
   mNavigator->selectItem( url );
   viewUrl( url, args, browserArgs );
@@ -347,7 +329,7 @@ void MainWindow::viewUrl( const QUrl &url, const KParts::OpenUrlArguments &args,
 
     QString proto = url.scheme().toLower();
 
-    if ( proto == "khelpcenter" ) {
+    if ( proto == QLatin1String("khelpcenter") ) {
       History::self().createEntry();
       mNavigator->openInternalUrl( url );
       return;
@@ -366,7 +348,7 @@ void MainWindow::viewUrl( const QUrl &url, const KParts::OpenUrlArguments &args,
     else if ( url.isLocalFile() ) {
         QMimeDatabase db;
         QMimeType mime = db.mimeTypeForUrl( url );
-        if ( mime.inherits("text/html") )
+        if ( mime.inherits(QStringLiteral("text/html")) )
             own = true;
     }
 
@@ -436,7 +418,7 @@ void MainWindow::slotGlossSelected(const GlossaryEntry &entry)
 {
     stop();
     History::self().createEntry();
-    mDoc->begin( QUrl( "glossentry:" + entry.id() ) );
+    mDoc->begin( QUrl( QStringLiteral("glossentry:") + entry.id() ) );
     mDoc->write( mDoc->grantleeFormatter()->formatGlossaryEntry( entry ) );
     mDoc->end();
 }
