@@ -69,11 +69,11 @@ void NavigatorAppGroupItem::setRelpath( const QString &relpath )
 
 void NavigatorAppGroupItem::itemExpanded(bool open)
 {
-  khcDebug() << "NavigatorAppGroupItem::itemExpanded()";
+  qCDebug(KHC_LOG) << "NavigatorAppGroupItem::itemExpanded()";
 
   if ( open && (childCount() == 0) && !mPopulated )
   {
-     khcDebug() << "  -> populate:" << this << "-" << mRelpath;
+     qCDebug(KHC_LOG) << "  -> populate:" << this << "-" << mRelpath;
      populate();
   }
   NavigatorItem::itemExpanded(open);
@@ -85,7 +85,7 @@ void NavigatorAppGroupItem::populate( bool recursive )
 
   KServiceGroup::Ptr root = KServiceGroup::group(mRelpath);
   if ( !root ) {
-    khcWarning() << "No Service groups for" << mRelpath;
+    qCWarning(KHC_LOG) << "No Service groups for" << mRelpath;
     return;
   }
   KServiceGroup::List list = root->entries();
@@ -112,9 +112,9 @@ void NavigatorAppGroupItem::populate( bool recursive )
       case KST_KServiceGroup:
       {
         const KServiceGroup::Ptr g(static_cast<KServiceGroup*>(e.data()));
-        if ( ( g->childCount() == 0 ) || g->name().startsWith( '.' ) )
+        if ( ( g->childCount() == 0 ) || g->name().startsWith( QLatin1Char('.') ) )
           continue;
-        DocEntry *entry = new DocEntry( g->caption(), "", g->icon() );
+        DocEntry *entry = new DocEntry( g->caption(), QString(), g->icon() );
         NavigatorAppGroupItem *appItem;
         appItem = new NavigatorAppGroupItem( entry, this, g->relPath() );
         appItem->setAutoDeleteDocEntry( true );
