@@ -1,3 +1,24 @@
+
+/*
+    This file is part of KHelpCenter.
+
+    Copyright (c) 2007 Andreas Pakulat <apaku@gmx.de>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include <QCoreApplication>
 #include <QDebug>
 
@@ -11,7 +32,7 @@ class MyTraverser : public DocEntryTraverser
   public:
     MyTraverser( const QByteArray &indent = "" ) : mIndent( indent ) {}
 
-    void process( DocEntry *entry ) Q_DECL_OVERRIDE
+    void process( DocEntry *entry ) override
     {
       qDebug() << mIndent.constData() << entry->name() << " - WEIGHT: " << entry->weight();
 #if 0
@@ -22,7 +43,7 @@ class MyTraverser : public DocEntryTraverser
 #endif
     }
   
-    DocEntryTraverser *createChild( DocEntry * ) Q_DECL_OVERRIDE
+    DocEntryTraverser *createChild( DocEntry * ) override
     {
       return new MyTraverser( mIndent + "  " );
     }
@@ -34,22 +55,22 @@ class MyTraverser : public DocEntryTraverser
 class LinearTraverser : public DocEntryTraverser
 {
   public:
-    void process( DocEntry *entry ) Q_DECL_OVERRIDE
+    void process( DocEntry *entry ) override
     {
       qDebug() << "PROCESS: " << entry->name();
     }
     
-    DocEntryTraverser *createChild( DocEntry * ) Q_DECL_OVERRIDE
+    DocEntryTraverser *createChild( DocEntry * ) override
     {
       return this;
     }
     
-    DocEntryTraverser *parentTraverser() Q_DECL_OVERRIDE
+    DocEntryTraverser *parentTraverser() override
     {
       return this;
     }
     
-    void deleteTraverser() Q_DECL_OVERRIDE {}
+    void deleteTraverser() override {}
 };
 
 class AsyncTraverser : public DocEntryTraverser
@@ -65,12 +86,12 @@ class AsyncTraverser : public DocEntryTraverser
 //      qDebug() << "~AsyncTraverser()";
     }
     
-    void process( DocEntry *entry ) Q_DECL_OVERRIDE
+    void process( DocEntry *entry ) override
     {
       qDebug() << mIndent.constData() << entry->name();
     }
     
-    DocEntryTraverser *createChild( DocEntry * ) Q_DECL_OVERRIDE
+    DocEntryTraverser *createChild( DocEntry * ) override
     {
 //      qDebug() << "AsyncTraverser::childTraverser()";
       return new AsyncTraverser( mIndent + "  " );
@@ -83,7 +104,7 @@ class AsyncTraverser : public DocEntryTraverser
 int main(int argc,char **argv)
 {
   QCoreApplication app(argc,argv);
-  QCoreApplication::setApplicationName( "khelpcenter" );
+  QCoreApplication::setApplicationName( QStringLiteral("khelpcenter") );
 
   qDebug() << "Scanning Meta Info";
 
